module Data.Serialize.Ldsf.Lean.InterfaceFunction (
      GetArguments
    , PutArguments
    , GetResult
    , PutResult
    , InterfaceFunction(..)
    ) where

import Data.Serialize.Get (Get)
import qualified Data.Serialize.Ldsf as Ldsf
import Data.Serialize.Ldsf.Types (Value)
import Data.Text (Text)
import Network.Lean.Types

type GetArguments = Get [Value]
type PutArguments = [Value] -> [Value]
type GetResult = Get [Value]
type PutResult = [Value] -> [Value]

-- | A representation of a function in a category.
data InterfaceFunction = InterfaceFunction
    { ldsfVersion :: Ldsf.Version -- ^ The LDSF version this function is compatible with.
    , category :: InterfaceCategory -- ^ The category this function belongs to.
    , version :: InterfaceVersion -- ^ The version of the function.
    , id :: InterfaceFunctionId -- ^ The id of the function.
    , name :: Text -- ^ The name of the function.
    , getArgs :: GetArguments -- ^ Parse arguments for this function.
    , putArgs :: PutArguments -- ^ Create arguments for this function.
    , getResult :: GetResult -- ^ Parse a result for this function.
    , putResult :: PutResult -- ^ Create a result for this function.
    }

-- TODO: instance show
