module Network.Lean.Types where

import Data.Serialize.Ldsf.Types (UInt8)

-- | The category interface.
data InterfaceCategory = Browser
                       | Text
                       | Image
                       | Video
                       | Forum
                       | Blog
                       | Search
                       deriving (Eq, Ord, Show)

-- | The version of the category interface.
type InterfaceVersion = UInt8

-- | The id of the function inside a category.
type InterfaceFunctionId = UInt8

-- | The response type.
data ResponseType = Ok
                  | BrowserError
                  | ClientError
                  | ServerError
                  | UnknownError
                  deriving (Eq, Show)

parseInterfaceCategory :: UInt8 -> Maybe InterfaceCategory
parseInterfaceCategory word = 
    case word of
         0 -> Just Browser
         1 -> Just Text
         2 -> Just Image
         3 -> Just Video
         4 -> Just Forum
         5 -> Just Search
         6 -> Just Blog
         _ -> Nothing

renderInterfaceCategory :: InterfaceCategory -> UInt8
renderInterfaceCategory category = 
    case category of
         Browser -> 0
         Text    -> 1
         Image   -> 2
         Video   -> 3
         Forum   -> 4
         Search  -> 5
         Blog    -> 6

parseResponseType :: UInt8 -> Maybe ResponseType
parseResponseType word =
    case word of
         0   -> Just Ok
         1   -> Just ClientError
         2   -> Just ServerError
         255 -> Just UnknownError
         _   -> Nothing

renderResponseType :: ResponseType -> UInt8
renderResponseType responseType =
    case responseType of
         Ok           -> 0
         BrowserError -> 1
         ClientError  -> 2
         ServerError  -> 3
         UnknownError -> 255
